import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import {
  GraduationCap,
  Users,
  Award,
  Globe,
  BookOpen,
  Target,
  Heart,
  Shield,
  Star,
  CheckCircle,
  ArrowRight,
  Lightbulb,
  TrendingUp,
  Clock,
  MessageSquare,
} from "lucide-react"

export default function AboutPage() {
  const stats = [
    { number: "5000+", label: "Happy Students", icon: <Users className="h-6 w-6" /> },
    { number: "500+", label: "Expert Writers", icon: <Award className="h-6 w-6" /> },
    { number: "50+", label: "Academic Fields", icon: <BookOpen className="h-6 w-6" /> },
    { number: "98%", label: "Satisfaction Rate", icon: <Star className="h-6 w-6" /> },
  ]

  const values = [
    {
      icon: <Shield className="h-8 w-8" />,
      title: "Academic Integrity",
      description:
        "We uphold the highest standards of academic honesty and original research in every project we undertake.",
      color: "from-blue-600 to-blue-700",
    },
    {
      icon: <Target className="h-8 w-8" />,
      title: "Excellence",
      description:
        "Our commitment to quality ensures that every piece of work meets rigorous academic standards and exceeds expectations.",
      color: "from-emerald-600 to-emerald-700",
    },
    {
      icon: <Heart className="h-8 w-8" />,
      title: "Student Success",
      description:
        "Your academic achievement is our primary goal. We're dedicated to helping you reach your educational objectives.",
      color: "from-amber-600 to-amber-700",
    },
    {
      icon: <Globe className="h-8 w-8" />,
      title: "Global Reach",
      description:
        "We serve students worldwide, understanding diverse educational systems and cultural academic requirements.",
      color: "from-purple-600 to-purple-700",
    },
  ]

  const team = [
    {
      name: "Dr. Sarah Johnson",
      role: "Chief Academic Officer",
      education: "PhD in Literature, Harvard University",
      specialization: "English Literature, Creative Writing",
      experience: "15+ years in academic writing and research",
      image: "/placeholder.svg?height=300&width=300",
    },
    {
      name: "Prof. Michael Chen",
      role: "Research Director",
      education: "PhD in Economics, Stanford University",
      specialization: "Economics, Business, Statistics",
      experience: "12+ years in economic research",
      image: "/placeholder.svg?height=300&width=300",
    },
    {
      name: "Dr. Emily Rodriguez",
      role: "Quality Assurance Lead",
      education: "PhD in Psychology, Yale University",
      specialization: "Psychology, Social Sciences",
      experience: "10+ years in academic publishing",
      image: "/placeholder.svg?height=300&width=300",
    },
    {
      name: "Dr. James Wilson",
      role: "STEM Writing Specialist",
      education: "PhD in Computer Science, MIT",
      specialization: "Computer Science, Engineering, Mathematics",
      experience: "8+ years in technical writing",
      image: "/placeholder.svg?height=300&width=300",
    },
  ]

  const milestones = [
    {
      year: "2018",
      title: "Foundation",
      description: "ProEssayWorks was founded with a mission to provide exceptional academic writing services.",
    },
    {
      year: "2019",
      title: "Team Expansion",
      description: "Grew our team to include PhD-qualified writers across 25+ academic disciplines.",
    },
    {
      year: "2020",
      title: "Global Reach",
      description: "Expanded services internationally, serving students from over 50 countries.",
    },
    {
      year: "2021",
      title: "Quality Certification",
      description: "Implemented comprehensive quality assurance processes and plagiarism detection systems.",
    },
    {
      year: "2022",
      title: "Technology Integration",
      description: "Launched our advanced platform with real-time communication and progress tracking.",
    },
    {
      year: "2023",
      title: "Academic Partnerships",
      description: "Established partnerships with leading academic institutions for research collaboration.",
    },
    {
      year: "2024",
      title: "Innovation Leader",
      description: "Recognized as a leader in academic writing services with 98% customer satisfaction.",
    },
  ]

  return (
    <div className="min-h-screen">
      {/* Header */}
      <header className="header-academic">
        <div className="container-academic">
          <div className="flex justify-between items-center py-4">
            <Link href="/" className="flex items-center">
              <div className="w-12 h-12 bg-navy rounded-lg flex items-center justify-center book-spine">
                <GraduationCap className="h-7 w-7 text-white" />
              </div>
              <span className="ml-3 text-2xl font-bold text-navy font-merriweather">ProEssayWorks</span>
            </Link>
            <nav className="hidden md:flex space-x-8">
              <Link href="/" className="nav-academic">
                Home
              </Link>
              <Link href="/services" className="nav-academic">
                Services
              </Link>
              <Link href="/how-it-works" className="nav-academic">
                How It Works
              </Link>
              <Link href="/pricing" className="nav-academic">
                Pricing
              </Link>
              <Link href="/about" className="nav-academic nav-academic-active">
                About
              </Link>
            </nav>
            <div className="flex space-x-3">
              <Link href="/auth/login">
                <Button variant="ghost" className="nav-academic font-medium">
                  Sign In
                </Button>
              </Link>
              <Link href="/auth/register">
                <Button className="btn-academic-primary">Get Started</Button>
              </Link>
            </div>
          </div>
        </div>
      </header>

      {/* Hero Section */}
      <section className="hero-academic section-academic-large">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h1 className="heading-academic-primary text-white">
              About ProEssayWorks
              <span className="block bg-gradient-to-r from-yellow-300 to-amber-300 bg-clip-text text-transparent mt-2">
                Empowering Academic Excellence
              </span>
            </h1>
            <p className="body-academic-large text-white/90">
              Since 2018, we've been dedicated to helping students achieve their academic goals through exceptional
              writing services, expert guidance, and unwavering commitment to quality.
            </p>
            <div className="flex flex-col sm:flex-row gap-4 justify-center max-w-lg mx-auto">
              <Link href="/auth/register?role=client">
                <Button className="btn-academic-secondary text-base px-8 py-4 w-full sm:w-auto">
                  Join Our Community
                  <ArrowRight className="ml-2 h-5 w-5" />
                </Button>
              </Link>
              <Link href="/services">
                <Button
                  variant="outline"
                  className="text-base px-8 py-4 w-full sm:w-auto text-white border-white hover:bg-white hover:text-navy"
                >
                  Our Services
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Stats Section */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="grid md:grid-cols-4 gap-8">
            {stats.map((stat, index) => (
              <Card key={index} className="card-academic text-center">
                <CardHeader>
                  <div className="w-16 h-16 bg-gradient-to-br from-navy to-navy-light rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                    {stat.icon}
                  </div>
                  <div className="text-4xl font-bold text-navy mb-2">{stat.number}</div>
                  <CardTitle className="text-lg font-bold text-navy">{stat.label}</CardTitle>
                </CardHeader>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Mission Section */}
      <section className="section-academic-large paper-texture">
        <div className="container-academic">
          <div className="grid lg:grid-cols-2 gap-16 items-center">
            <div>
              <h2 className="heading-academic-secondary mb-8">Our Mission</h2>
              <p className="body-academic-large mb-6">
                At ProEssayWorks, we believe that every student deserves access to exceptional academic support. Our
                mission is to bridge the gap between academic challenges and student success through personalized,
                high-quality writing services.
              </p>
              <p className="body-academic-regular mb-8">
                We're not just a writing service – we're your academic partners, committed to helping you develop
                critical thinking skills, improve your writing abilities, and achieve your educational goals. Our team
                of PhD-qualified experts brings decades of combined experience to support your academic journey.
              </p>
              <div className="space-y-4">
                <div className="flex items-center">
                  <CheckCircle className="h-6 w-6 text-emerald-600 mr-4" />
                  <span className="body-academic-regular">Personalized academic support for every student</span>
                </div>
                <div className="flex items-center">
                  <CheckCircle className="h-6 w-6 text-emerald-600 mr-4" />
                  <span className="body-academic-regular">Commitment to academic integrity and originality</span>
                </div>
                <div className="flex items-center">
                  <CheckCircle className="h-6 w-6 text-emerald-600 mr-4" />
                  <span className="body-academic-regular">Continuous improvement and innovation in education</span>
                </div>
              </div>
            </div>
            <div className="relative">
              <div className="w-full h-96 bg-gradient-to-br from-navy to-navy-light rounded-2xl flex items-center justify-center text-white">
                <div className="text-center">
                  <BookOpen className="h-24 w-24 mx-auto mb-6 opacity-80" />
                  <h3 className="text-2xl font-bold mb-4">Academic Excellence</h3>
                  <p className="text-lg opacity-90">Empowering students worldwide</p>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Values Section */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Our Core Values</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              These fundamental principles guide everything we do and shape our commitment to academic excellence.
            </p>
          </div>

          <div className="grid lg:grid-cols-2 gap-8">
            {values.map((value, index) => (
              <Card key={index} className="card-academic">
                <CardHeader>
                  <div className="flex items-center mb-4">
                    <div
                      className={`w-16 h-16 bg-gradient-to-br ${value.color} rounded-lg flex items-center justify-center text-white mr-6`}
                    >
                      {value.icon}
                    </div>
                    <CardTitle className="heading-academic-tertiary">{value.title}</CardTitle>
                  </div>
                </CardHeader>
                <CardContent>
                  <p className="body-academic-regular text-gray-cool">{value.description}</p>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Team Section */}
      <section className="section-academic-large paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Meet Our Leadership Team</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Our experienced academic professionals bring decades of combined expertise in research, writing, and
              education to support your success.
            </p>
          </div>

          <div className="grid lg:grid-cols-2 gap-12">
            {team.map((member, index) => (
              <Card key={index} className="card-academic">
                <CardHeader>
                  <div className="flex items-start space-x-6">
                    <div className="w-24 h-24 bg-gradient-to-br from-navy to-navy-light rounded-full flex items-center justify-center text-white flex-shrink-0">
                      <Users className="h-12 w-12" />
                    </div>
                    <div className="flex-1">
                      <CardTitle className="text-xl font-bold text-navy mb-2">{member.name}</CardTitle>
                      <Badge variant="outline" className="text-navy border-navy mb-3">
                        {member.role}
                      </Badge>
                      <CardDescription className="body-academic-regular">{member.education}</CardDescription>
                    </div>
                  </div>
                </CardHeader>
                <CardContent>
                  <div className="space-y-3">
                    <div>
                      <span className="font-semibold text-navy">Specialization: </span>
                      <span className="body-academic-regular text-gray-cool">{member.specialization}</span>
                    </div>
                    <div>
                      <span className="font-semibold text-navy">Experience: </span>
                      <span className="body-academic-regular text-gray-cool">{member.experience}</span>
                    </div>
                  </div>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Timeline Section */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Our Journey</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              From a small startup to a leading academic writing service, here's how we've grown and evolved.
            </p>
          </div>

          <div className="relative">
            <div className="absolute left-1/2 transform -translate-x-1/2 w-1 h-full bg-gradient-to-b from-navy to-navy-light"></div>
            <div className="space-y-12">
              {milestones.map((milestone, index) => (
                <div key={index} className={`flex items-center ${index % 2 === 0 ? "flex-row" : "flex-row-reverse"}`}>
                  <div className={`w-1/2 ${index % 2 === 0 ? "pr-8 text-right" : "pl-8 text-left"}`}>
                    <Card className="card-academic">
                      <CardHeader>
                        <div className="flex items-center justify-between">
                          <Badge className="bg-navy text-white">{milestone.year}</Badge>
                          <TrendingUp className="h-5 w-5 text-navy" />
                        </div>
                        <CardTitle className="text-xl font-bold text-navy">{milestone.title}</CardTitle>
                      </CardHeader>
                      <CardContent>
                        <p className="body-academic-regular text-gray-cool">{milestone.description}</p>
                      </CardContent>
                    </Card>
                  </div>
                  <div className="relative z-10 w-6 h-6 bg-navy rounded-full border-4 border-white shadow-lg"></div>
                  <div className="w-1/2"></div>
                </div>
              ))}
            </div>
          </div>
        </div>
      </section>

      {/* Why Choose Us */}
      <section className="section-academic paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Why Students Choose ProEssayWorks</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Discover what sets us apart in the academic writing industry and why thousands of students trust us.
            </p>
          </div>

          <div className="grid md:grid-cols-3 gap-8">
            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-blue-600 to-blue-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <Lightbulb className="h-8 w-8" />
                </div>
                <CardTitle className="heading-academic-tertiary">Innovation</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  We continuously innovate our processes and technology to provide the best possible experience for our
                  students and maintain our position as industry leaders.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-emerald-600 to-emerald-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <Clock className="h-8 w-8" />
                </div>
                <CardTitle className="heading-academic-tertiary">Reliability</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  With a 98% on-time delivery rate and 24/7 customer support, you can count on us to be there when you
                  need us most, every step of the way.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-amber-600 to-amber-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <MessageSquare className="h-8 w-8" />
                </div>
                <CardTitle className="heading-academic-tertiary">Communication</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  Direct communication with your assigned writer, real-time progress updates, and responsive customer
                  service ensure you're always informed and involved.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="section-academic hero-academic">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h2 className="heading-academic-secondary text-white">Ready to Join Our Academic Community?</h2>
            <p className="body-academic-large text-white/90">
              Become part of a community dedicated to academic excellence, scholarly achievement, and educational
              success.
            </p>
            <div className="flex flex-col sm:flex-row gap-6 justify-center max-w-lg mx-auto">
              <Link href="/auth/register?role=client">
                <Button className="btn-academic-secondary text-base px-8 py-4 w-full sm:w-auto">
                  Get Started Today
                  <ArrowRight className="ml-2 h-5 w-5" />
                </Button>
              </Link>
              <Link href="/auth/register?role=writer">
                <Button
                  variant="outline"
                  className="text-base px-8 py-4 w-full sm:w-auto text-white border-white hover:bg-white hover:text-navy"
                >
                  Join Our Team
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-navy text-white section-academic">
        <div className="container-academic">
          <div className="grid md:grid-cols-4 gap-10">
            <div className="space-y-8">
              <div className="flex items-center">
                <div className="w-12 h-12 bg-navy-light rounded-lg flex items-center justify-center book-spine">
                  <GraduationCap className="h-7 w-7 text-white" />
                </div>
                <span className="ml-3 text-2xl font-bold font-merriweather">ProEssayWorks</span>
              </div>
              <p className="body-academic-regular text-white/80">
                Empowering academic excellence through distinguished scholarship and expert writing services.
              </p>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Quick Links</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li>
                  <Link href="/" className="hover:text-white transition-colors">
                    Home
                  </Link>
                </li>
                <li>
                  <Link href="/services" className="hover:text-white transition-colors">
                    Services
                  </Link>
                </li>
                <li>
                  <Link href="/how-it-works" className="hover:text-white transition-colors">
                    How It Works
                  </Link>
                </li>
                <li>
                  <Link href="/pricing" className="hover:text-white transition-colors">
                    Pricing
                  </Link>
                </li>
                <li>
                  <Link href="/about" className="hover:text-white transition-colors">
                    About
                  </Link>
                </li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Services</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Research Papers</li>
                <li className="hover:text-white transition-colors cursor-pointer">Essays</li>
                <li className="hover:text-white transition-colors cursor-pointer">Dissertations</li>
                <li className="hover:text-white transition-colors cursor-pointer">Case Studies</li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Support</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Contact Us</li>
                <li className="hover:text-white transition-colors cursor-pointer">FAQ</li>
                <li className="hover:text-white transition-colors cursor-pointer">Privacy Policy</li>
                <li className="hover:text-white transition-colors cursor-pointer">Terms of Service</li>
              </ul>
            </div>
          </div>
          <div className="border-t border-navy-light mt-16 pt-10 text-center">
            <p className="body-academic-regular text-white/70">&copy; 2024 ProEssayWorks. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </div>
  )
}
